@@ -1,12 +1,15 @@
 #' Generate fake data based on provided schema specification
 #'
 #' @name DataFakeR-package
+#' @keywords internal
 #' @importFrom magrittr %>%
 
 globalVariables(c(
   ":=", "!!", ".", "from", "to", ".data", "nodes",
   "nchars", "vals", "val", "constraint_type", "table_name",
-  "unique_constraint_name", "column_name", "name"
+  "unique_constraint_name", "column_name", "name",
+  "constraint_name", "data_type", "character_maximum_length",
+  "old_ind"
 ))
 
 NULL
